
/****************************************************************************
 *
 * All portions copyright their respective authors.  All rights reserved.
 *
 * This file is part of IVMan (ivm).
 *
 * This file may be distributed under the terms of the Q Public License
 * as defined by Troll Tech AS of Norway and appearing in the file
 * LICENSE.QPL included in the packaging of this file.
 * 
 * See http://www.troll.no/qpl for QPL licensing information.
 *
 * $Id: IvmConfigBase.h,v 1.13 2005/11/06 12:29:47 ro_han Exp $
 *****************************************************************************/

#ifndef _IVMCONFIGBASE_H
#define _IVMCONFIGBASE_H

#include <glib.h>

typedef struct IvmConfigBase
{
    gboolean fork;
    gboolean debug;
    gboolean sleep;
    char *configPath;
    char *pidFile;
    char *user;
    char *group;
    char *mountcommand;
    char *umountcommand;
    char *umask;
} IvmConfigBase;

IvmConfigBase *parseIvmConfigBase(char const *const path);
#endif
